@@ -11,7 +11,7 @@ use Data::Dumper;
 use File::Find;
 use Safe;
 
-our $VERSION = '1.10';
+our $VERSION = '1.13';
 
 $Data::Dumper::Terse = 1;  # Don't output variable names.
 $Data::Dumper::Sortkeys = 1;  # Sort the content of the hash variables.
@@ -52,20 +52,20 @@ sub maybe_expand_dirs {
         # Because of the follow option, a stat has already been done on the file,
         # so the '_' magic is guaranteed to work.
         wanted => sub {
-            if (-f _) {
-              my $f = $_;
-              if (defined $filter) {
-                my $r = $filter->();
-                return if warn_or_die_if_needed(
-                    'Perl code failed while filtering input') || !$r;
-              }
-              push @files, $f;
+          if (-f _) {
+            if (defined $filter) {
+              local $_ = $_;
+              my $r = $filter->();
+              return if warn_or_die_if_needed('Perl code failed while filtering input') || !$r;
             }
-        } ,
+            push @files, $_;
+          }
+        },
         follow => 1,
         no_chdir => 1,
-    }, $f);
-    return sort @files;
+      },
+      $f);
+    return (sort @files);
   } else {
     # We assume that everything else is a file.
     return $f;
@@ -79,24 +79,20 @@ sub process_all {
     print "Merging all the inputs.\n" if $options->{debug_mode};
     my $missing_final_separator = 0;
     my @content;
-    for my $input (@$inputs) {
-      my ($content, $missing_separator) =
-          read_input($input, $options, $stdin);
-      push @content, @$content;
+    for my $input (@{$inputs}) {
+      my ($content, $missing_separator) = read_input($input, $options, $stdin);
+      push @content, @{$content};
       $missing_final_separator = $missing_separator;
     }
-    App::PTP::Commands::process(
-        \$App::PTP::Files::merged_marker, $pipeline, $options, \@content,
-        $missing_final_separator);
-    write_output(\$App::PTP::Files::merged_marker, \@content,
-                 $missing_final_separator, $options);
+    App::PTP::Commands::process(\$App::PTP::Files::merged_marker,
+      $pipeline, $options, \@content, $missing_final_separator);
+    write_output(\$App::PTP::Files::merged_marker, \@content, $missing_final_separator, $options);
   } else {
-    for my $file_name (@$inputs) {
-      my ($content, $missing_final_separator) =
-          read_input($file_name, $options, $stdin);
+    for my $file_name (@{$inputs}) {
+      my ($content, $missing_final_separator) = read_input($file_name, $options, $stdin);
       # Note that process can modify the input $file_name variable.
       App::PTP::Commands::process($file_name, $pipeline, $options, $content,
-                                  $missing_final_separator);
+        $missing_final_separator);
       write_output($file_name, $content, $missing_final_separator, $options);
       $App::PTP::Commands::I_setter->inc();
     }
@@ -105,9 +101,9 @@ sub process_all {
 
 sub Run {
   my ($stdin, $stdout, $stderr, $argv) = @_;
-  select($stderr);  # All debug output, this applies inside the safe too.
-  my ($inputs, $pipeline, $options) =
-      App::PTP::Args::parse_command_line($argv);
+  # All debug output is sent to STDERR, this applies inside the safe too.
+  select($stderr);  ## no critic (ProhibitOneArgSelect)
+  my ($inputs, $pipeline, $options) = App::PTP::Args::parse_command_line($argv);
 
   if ($options->{debug_mode}) {
     print 'options = '.Dumper($options)."\n";
@@ -115,7 +111,7 @@ sub Run {
     print 'pipeline = '.Dumper($pipeline)."\n";
   }
 
-  @$inputs = map { maybe_expand_dirs($_, $options) } @$inputs;
+  @{$inputs} = map { maybe_expand_dirs($_, $options) } @{$inputs};
   print 'expanded @inputs = '.Dumper($inputs)."\n" if $options->{debug_mode};
 
   return if $options->{abort};
